package cd.casic.ci.process.process.service.taskResource.impl;

import cd.casic.ci.process.dto.req.taskResource.TaskResourceQueryReq;
import cd.casic.ci.process.dto.resp.taskResource.TaskResourceFindResp;
import cd.casic.ci.process.process.dao.taskResource.*;
import cd.casic.ci.process.process.dataObject.taskResource.*;
import cd.casic.ci.process.process.service.taskResource.TaskResourceManagerService;
import cd.casic.framework.commons.exception.ServiceException;
import cd.casic.framework.commons.exception.enums.GlobalErrorCodeConstants;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.util.ObjectUtils;

import java.util.List;

/**
 * @author HopeLi
 * @version v1.0
 * @ClassName ResourceServiceImpl
 * @Date: 2025/5/13 10:31
 * @Description:
 */
//@Service
@Slf4j
public class TaskResourceManagerServiceImpl implements TaskResourceManagerService {
//public class TaskResourceManagerServiceImpl extends ServiceImpl<ResourceManagerDao, ResourceManager> implements TaskResourceManagerService {

    @Resource
    private ResourceMachineDao machineDao;

    @Resource
    private ResourceDockerEndpointDao dockerEndpointDao;

    @Resource
    private ResourceK8SDao k8SDao;

    @Resource
    private ResourceCloudDao cloudDao;



    @Override
    public TaskResourceFindResp findResourceList(TaskResourceQueryReq query) {
        TaskResourceFindResp taskResourceFindResp = new TaskResourceFindResp();

        if (StringUtils.isEmpty(query.getType())){
            throw new ServiceException(GlobalErrorCodeConstants.INTERNAL_SERVER_ERROR.getCode(),"资源类型不可为空");
        }

        switch (query.getType()) {
            case "docker":
                List<ResourceDockerEndpoint> resourceDockerEndpoints = dockerEndpointDao.selectList(new QueryWrapper<>());
                if (!ObjectUtils.isEmpty(resourceDockerEndpoints)){
                    taskResourceFindResp.setDockerEndpointList(resourceDockerEndpoints);
                }
                return taskResourceFindResp;
            case "k8s":
                List<ResourceK8S> resourceK8S = k8SDao.selectList(new QueryWrapper<>());
                if (!ObjectUtils.isEmpty(resourceK8S)){
                    taskResourceFindResp.setResourceK8SList(resourceK8S);
                }
                return taskResourceFindResp;
            case "machine":
                List<ResourceMachine> resourceMachines = machineDao.selectList(new QueryWrapper<>());
                if (!ObjectUtils.isEmpty(resourceMachines)){
                    taskResourceFindResp.setResourceMachineList(resourceMachines);
                }
                return taskResourceFindResp;
            case "cloud":
                List<ResourceCloud> resourceClouds = cloudDao.selectList(new QueryWrapper<>());
                if (!ObjectUtils.isEmpty(resourceClouds)){
                    taskResourceFindResp.setResourceCloudList(resourceClouds);
                }
                return taskResourceFindResp;
            default:
                throw new ServiceException(GlobalErrorCodeConstants.INTERNAL_SERVER_ERROR.getCode(),"资源类型错误");
        }
    }
}
